A small reqwest-like HTTP client built over a caller-provided Hyper service.
The client automatically stores Set-Cookie response headers and attaches
matching cookies to later requests. The cookie store is enabled by default.
Structs
- Body
- The request body accepted by
HttpService. - Bytes
- A cheaply cloneable and sliceable chunk of contiguous memory.
- Client
- A configurable HTTP client backed by an
HttpService. - Client
Builder - Request
Builder - Response
- Standard
Client Builder - A reqwest-like builder for a standard client, including Hyper pool tuning.
- Standard
Service - A Hyper transport service using the regular Tokio networking stack.
- Status
Code - An HTTP status code (
status-codein RFC 9110 et al.). - Version
- Represents a version of the HTTP spec.
Enums
Traits
- Http
Service - A cloneable Hyper-compatible request service.
Functions
- standard_
client - Build a reqwest-like client with standard networking and cookies enabled.
- standard_
client_ builder - Build a configurable standard client.
- standard_
connector - Build a standard connector supporting HTTP/1.1, HTTP/2, and Web PKI roots.
- standard_
hyper_ client - Build a raw Hyper client running on Tokio’s networking stack.
- standard_
service - Build a standard Hyper transport for use with
Client::builder.
Type Aliases
- BoxError
- Standard
Client - A cookie-aware client using the regular Tokio networking stack.
- Standard
Connector - The conventional Tokio connector used for direct HTTP and HTTPS requests.
- Standard
Hyper Client - A raw Hyper client using
StandardConnector.